<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>Autentificare necesară pentru citire informații disc</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Rularea Manager Disc Necesită Autentificare</translation>
		</message>
	</context>
</TS>